@@ -331,7 +331,7 @@ class TestInstrumentPid(Test):
 class TestTimeVector(Test):
     def run(self):
         time = self.nc["time"][:]
-        if len(time) == 1:
+        if time.shape == () or len(time) == 1:
             self._add_message("One time step only.")
             return
         differences = np.diff(time)
@@ -363,7 +363,21 @@ class TestVariableNames(Test):
 @test("Test that file passes CF convention")
 class TestCFConvention(Test):
     def run(self):
-        inst = cfchecks.CFChecker(silent=True, version="1.8", cacheTables=True, cacheDir="/tmp")
+        standard_names = "CF_STANDARD_NAMES_XML"
+        area_types = "CF_AREA_TYPES_XML"
+        region_names = "CF_REGION_NAMES_XML"
+        cf_version = "1.8"
+        env = os.environ
+        if all(key in env for key in (standard_names, area_types, region_names)):
+            inst = cfchecks.CFChecker(
+                silent=True,
+                version=cf_version,
+                cfStandardNamesXML=env[standard_names],
+                cfAreaTypesXML=env[area_types],
+                cfRegionNamesXML=env[region_names],
+            )
+        else:
+            inst = cfchecks.CFChecker(silent=True, version=cf_version)
         result = inst.checker(str(self.filename))
         for key in result["variables"]:
             for level, error_msg in result["variables"][key].items():
